dcMRI
=====

.. image:: https://github.com/QIB-Sheffield/dcmri/actions/workflows/pytest-actions.yaml/badge.svg?branch=dev
  :target: https://github.com/QIB-Sheffield/dcmri/actions/workflows/pytest-actions.yaml

.. image:: https://codecov.io/gh/plaresmedima/dcmri/graph/badge.svg?token=DLVVTWQ0HA 
  :target: https://codecov.io/gh/plaresmedima/dcmri

.. image:: https://img.shields.io/pypi/v/dcmri?label=pypi%20package 
  :target: https://pypi.org/project/dcmri/

.. image:: https://img.shields.io/pypi/dm/dcmri
  :target: https://pypistats.org/packages/dcmri

.. image:: https://img.shields.io/badge/License-Apache_2.0-blue.svg
  :target: https://opensource.org/licenses/Apache-2.0


**Note:** *dcMRI is under construction. The first stable version with more comprehensive functionality and documentation will be v1.0.0. Before that the API may still change and features may be deprecated without warning.*


dcMRI is a python toolbox for dynamic contrast MRI.

- **Documentation:** https://qib-sheffield.github.io/dcmri
- **Source:** https://github.com/QIB-Sheffield/dcmri
- **PyPi release:** https://pypi.org/project/dcmri/


Install
-------

Install the latest version of dcMRI::

    $ pip install dcmri


License
-------

Released under the Apache 2.0 license (https://opensource.org/licenses/Apache-2.0)::

   Copyright (C) 2023-2024 dcMRI developers
   Ebony Gunwhy <e.gunwhy@sheffield.ac.uk>
   Steven Sourbron <s.sourbron@sheffield.ac.uk>